# O'lang

#### _A fun programing language with odia keywords..._

<p align="center">
 <h3>Do you know odia?</h3>
  <h5>If your answer is yes then you seriously gonna have fun!!!</h5>
</p>

### Keywords

- o'lang is currently extended with the following keywords.

| GENERALLY   | IN O'LANG         |
| ----------- | ----------------- |
| print       | LEKHE             |
| function    | FALANA            |
| run         | CHALA             |
| len         | LAMBA             |
| var         | CHALA_RASI        |
| and         | ABOM              |
| or          | KIMBA             |
| true        | THEEK             |
| flase       | BHUL              |
| if          | JADI              |
| else        | ANYATHA           |
| elif        | ANJA(ANYTHA JADI) |
| to          | KU                |
| for         | PAEN              |
| end         | SESHA             |
| break       | BIRATI            |
| step        | PADANKA           |
| while       | JETEBELE          |
| then        | TAPARE            |
| return      | FERA              |
| continue    | CHALU             |
| null        | KICHHI_NAHI       |
| math_pi     | GANITA_PI         |
| input()     | NE()              |
| print       | LEKHE             |
| clear       | KHALI_KARE        |
| cls         | SAFA              |
| is_number   | SANKHYA_KI        |
| is_string   | BAKYA_KI          |
| is_list     | TALIKA_KI         |
| is_function | FALANA_KI         |
| append      | JODA              |
| extended    | BADHA             |
| pop         | KADHA             |

### How to use?

- install O-lang like the below
```sh
pip install O-lang
```
- open terminal and start python prompt like the below
```sh
python
```
- then run the below
```sh
import olang
```
- create a file, write your code and save the file as <file_name.ol>
- then run the below

```sh
CHALA("<your_file_name>.ol")
```
- Have fun with this beautiful tool.

### Example

```sh
#input
LEKHE("Input Dia:")
CHALA_RASI X = NE()

#print
LEKHE(X)

#function
FALANA misa(a,b)
	LEKHE(a+b)
SESHA

#function call
misa(5,6)

#for looop
PAEN i = 0 KU 5 TAPARE
		LEKHE(i)
SESHA
```

### Connect with me

- [GitHub](https://github.com/saurabh190802)
- [LinkedIn](https://www.linkedin.com/in/saurabh-satapathy-692a6a1b9/)
- [Twitter](https://twitter.com/SaurabhSatapat1)
